aboutsummaryrefslogtreecommitdiffhomepage
path: root/lib/sisu/v0/sysenv.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/sisu/v0/sysenv.rb')
-rw-r--r--lib/sisu/v0/sysenv.rb106
1 files changed, 57 insertions, 49 deletions
diff --git a/lib/sisu/v0/sysenv.rb b/lib/sisu/v0/sysenv.rb
index a0e519b3..f1aa19fc 100644
--- a/lib/sisu/v0/sysenv.rb
+++ b/lib/sisu/v0/sysenv.rb
@@ -1,50 +1,58 @@
=begin
- * Name: SiSU information Structuring Universe - Structured information, Serialized Units
+
+ * Name: SiSU
+
+ * Description: a framework for document structuring, publishing and search
+
* Author: Ralph Amissah
- * http://www.jus.uio.no/sisu
- * http://www.jus.uio.no/sisu/SiSU/download.html
- * Description: system environment, resource control and configuration details
+ * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+ 2007 Ralph Amissah All Rights Reserved.
- * Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007 Ralph Amissah
+ * License: GPL 3 or later:
- * License: GPL 2 or later
+ SiSU, a framework for document structuring, publishing and search
- Summary of GPL 2
+ Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
+ 2007 Ralph Amissah
- This program is free software; you can redistribute it and/or modify it
- under the terms of the GNU General Public License as published by the Free
- Software Foundation; either version 2 of the License, or (at your option)
- any later version.
+ This program is free software: you can redistribute it and/or modify it
+ under the terms of the GNU General Public License as published by the Free
+ Software Foundation, either version 3 of the License, or (at your option)
+ any later version.
- This program is distributed in the hope that it will be useful, but WITHOUT
- ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
- more details.
+ This program is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
+ more details.
- You should have received a copy of the GNU General Public License along
- with this program; if not, write to the Free Software Foundation, Inc.,
- 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ You should have received a copy of the GNU General Public License along with
+ this program. If not, see <http://www.gnu.org/licenses/>.
- If you have Internet connection, the latest version of the GPL should be
- available at these locations:
- http://www.fsf.org/licenses/gpl.html
- http://www.gnu.org/copyleft/gpl.html
- http://www.jus.uio.no/sisu/gpl2.fsf
+ If you have Internet connection, the latest version of the GPL should be
+ available at these locations:
+ <http://www.fsf.org/licenses/gpl.html>
+ <http://www.gnu.org/copyleft/gpl.html>
+ <http://www.jus.uio.no/sisu/gpl.fsf>
- SiSU was first released to the public on January 4th 2005
+ * SiSU uses:
+ * Standard SiSU markup syntax,
+ * Standard SiSU meta-markup syntax, and the
+ * Standard SiSU object citation numbering and system
- SiSU uses:
+ * Hompages:
+ <http://www.jus.uio.no/sisu>
+ <http://www.sisudoc.org>
- * Standard SiSU markup syntax,
- * Standard SiSU meta-markup syntax, and the
- * Standard SiSU object citation numbering and system
+ * Download:
+ <http://www.jus.uio.no/sisu/SiSU/download.html>
- © Ralph Amissah 1997, current 2007.
- All Rights Reserved.
+ * Ralph Amissah
+ <ralph@amissah.com>
+ <ralph.amissah@gmail.com>
+
+ ** Description: system environment, resource control and configuration details
- * Ralph Amissah: ralph@amissah.com
- ralph.amissah@gmail.com
=end
@@cX=nil
@@current_document=Dir.pwd #nil #''
@@ -167,7 +175,7 @@ module SiSU_Env
LANGUAGE => 'English',
LANGUAGE_CODE => 'en', #change, unecessary duplication though currently used
MULTILINGUAL => true,
- CONCORD_MAX => 200000,
+ CONCORD_MAX => 260000,
DIGEST => 'md5',
WEBSERV_HOST_CGI => 'http://localhost',
WEBSERV_PORT_CGI => 8081, #8111,8123,8081
@@ -858,10 +866,10 @@ module SiSU_Env
end
if create_form
%{<td align="center" bgcolor="#ffffff">
-<!-- Search SiSU -->
+<!-- SiSU Search -->
<a name="search"></a>
-<font size="2">
<form method="get" action="#{rc['search']['action']}" target="_top">
+<font size="2">
<input type="text" name="s1" size="24" maxlength="255" />
<br />
<input type="hidden" name="db" value="#{db}" />
@@ -872,9 +880,9 @@ module SiSU_Env
<input type="radio" name="view" value="text" /> txt
<input type="submit" name="ignore" value="search" />
<input type="checkbox" name="fns" value="#{@md.fnb}" />
-</form>
</font>
-<!-- Search SiSU -->
+</form>
+<!-- SiSU Search -->
</td> }
else ''
end
@@ -894,10 +902,10 @@ module SiSU_Env
end
if create_form
%{<td align="center" bgcolor="#ffffff">
-<!-- Search SiSU -->
+<!-- SiSU Search -->
<a name="search"></a>
-<font size="2">
<form method="get" action="#{rc['search']['action']}" target="_top">
+<font size="2">
<input type="text" name="s1" size="24" maxlength="255" />
<br />
<input type="hidden" name="db" value="#{db}" />
@@ -908,9 +916,9 @@ module SiSU_Env
<input type="radio" name="view" value="text" /> txt
<input type="submit" name="ignore" value="search" />
<input type="checkbox" name="fns" value="#{@md.fnb}" />
-</form>
</font>
-<!-- Search SiSU -->
+</form>
+<!-- SiSU Search -->
</td> }
else ''
end
@@ -972,10 +980,10 @@ module SiSU_Env
else false
end
if create_form and @fnb and @fnb=~/\S+/
- %{<!-- Search SiSU -->
+ %{<!-- SiSU Search -->
<a name="search"></a>
-<font size="2">
<form method="get" action="#{rc['search']['action']}" target="_top">
+<font size="2">
<input type="text" name="s1" size="24" maxlength="255" />
<br />
<input type="hidden" name="db" value="#{db}" />
@@ -984,14 +992,14 @@ module SiSU_Env
<input type="radio" name="view" value="index" /> idx
<input type="radio" name="view" value="text" checked="checked" /> txt
<input type="submit" name="ignore" value="search" />
-</form>
</font>
-<!-- Search SiSU --> }
+</form>
+<!-- SiSU Search --> }
elsif create_form
- %{<!-- Search SiSU -->
+ %{<!-- SiSU Search -->
<a name="search"></a>
-<font size="2">
<form method="get" action="#{rc['search']['action']}" target="_top">
+<font size="2">
<input type="text" name="s1" size="24" maxlength="255" />
<br />
<input type="hidden" name="db" value="#{db}" />
@@ -999,9 +1007,9 @@ module SiSU_Env
<input type="radio" name="view" value="index" checked="checked" /> idx
<input type="radio" name="view" value="text" /> txt
<input type="submit" />
-</form>
</font>
-<!-- Search SiSU --> }
+</form>
+<!-- SiSU Search --> }
else ''
end
end